.. image:: https://img.shields.io/pypi/v/jaraco.media.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/jaraco.media.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/jaraco.media

.. image:: https://github.com/jaraco/jaraco.media/workflows/tests/badge.svg
   :target: https://github.com/jaraco/jaraco.media/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. .. image:: https://readthedocs.org/projects/skeleton/badge/?version=latest
..    :target: https://skeleton.readthedocs.io/en/latest/?badge=latest

Troubleshooting
---------------

If you see "libaacs not initialized!" or "aacs_open() failed",
remember that you have to re-register with the latest
beta key each month.

See `this blog
<http://drbobtechblog.com/handbrake-can-use-makemkv-to-automatically-process-blu-ray-discs-heres-how/>`_
for details.
